@@ -29,8 +29,8 @@
 #define debugParser 0
 //#include "dinterpreter.hpp"
 
-// defintion in dinterpreter.cpp
-//void SetActualCompileOpt( unsigned int cOpt);
+// definition in dinterpreter.cpp
+void MemorizeCompileOptForMAINIfNeeded( unsigned int cOpt);
 
 class CUSTOM_API GDLLexer : public antlr::CharScanner, public GDLTokenTypes
 {
