@@ -26,12 +26,6 @@
 
 #include <string>
 
-#if defined(__GNUC__) && !defined(__INTEL_COMPILER)
-// by default intel C++ defines __GNUC__
-#pragma interface
-#endif
-
-
 // for each group we need one definition
 // usage: GDL_DEFINE_INTEGER_FUNCTION(retType) fName( arg list) { definition}
 #define GDL_DEFINE_INTEGER_FUNCTION( retType ) template<typename Sp>template< typename U> typename U::template IfInteger< retType >::type Data_<Sp>::
@@ -470,7 +464,7 @@ static	void operator delete( void *ptr);
   SizeT OFmtA( std::ostream* os, SizeT offset, SizeT num, int width, const int code=0);
   SizeT OFmtF( std::ostream* os, SizeT offs, SizeT num, int width, int prec, const int code=0, const BaseGDL::IOMode oM = BaseGDL::FIXED);
   SizeT OFmtI( std::ostream* os, SizeT offs, SizeT num, int width, int minN, int code=0, BaseGDL::IOMode oM = BaseGDL::DEC);
-  SizeT OFmtCal( std::ostream* os, SizeT offs, SizeT num, int width, int minN, char *f, int code=0, BaseGDL::Cal_IOMode oM = BaseGDL::DEFAULT);
+  SizeT OFmtCal( std::ostream* os, SizeT offs, SizeT num, int width, int minN, const std::string &s, int code=0, BaseGDL::Cal_IOMode oM = BaseGDL::DEFAULT);
   // formatting input functions
   SizeT IFmtA( std::istream* is, SizeT offset, SizeT num, int width); 
   SizeT IFmtF( std::istream* is, SizeT offs, SizeT num, int width); 
@@ -495,10 +489,10 @@ private:
 
 };
 
-// template<> Data_<SpDPtr>::Data_(const Ty& d_);
-// template<> Data_<SpDObj>::Data_(const Ty& d_);
+template<> Data_<SpDObj>::Data_(const dimension& dim_, BaseGDL::InitType iT, DDouble, DDouble);
+template<> Data_<SpDPtr>::Data_(const dimension& dim_, BaseGDL::InitType iT, DDouble, DDouble);
+template<> SizeT Data_<SpDObj>::N_Elements() const;
 
-#include "specializations.hpp"
 
 typedef Data_<SpDByte>       DByteGDL;
 typedef Data_<SpDInt>        DIntGDL;
