@@ -18,25 +18,11 @@
 #ifndef DEVICEZ_HPP_
 #define DEVICEZ_HPP_
 
+static const PLFLT Z_DPI = 96 ; //in dpi;
+
 //#include "dstructgdl.hpp"
 #include "gdlzstream.hpp"
 
-#if defined (_MSC_VER) && (_MSC_VER < 1800)
-/* replacement of Unix rint() for Windows */
-static int rint (double x)
-{
-char *buf;
-int i,dec,sig;
-
-buf = _fcvt(x, 0, &dec, &sig);
-i = atoi(buf);
-if(sig == 1) {
-i = i * -1;
-}
-return(i);
-}
-#endif
-
 class DeviceZ: public GraphicsDevice
 {
   GDLZStream*     actStream;
@@ -44,7 +30,8 @@ class DeviceZ: public GraphicsDevice
   char*  memBuffer;
   DInt*  zBuffer;
   int    decomposed;
-  
+  DString fontname;
+    
   void SetZBuffer( DLong x, DLong y)
   {
     delete[] zBuffer;
@@ -107,24 +94,26 @@ class DeviceZ: public GraphicsDevice
       { r[ i] = g[ i] = b[ i] = i;}
     actStream->SetColorMap0( r, g, b, ctSize); 
     actStream->SetColorMap1( r, g, b, ctSize); 
+    
+  short myfont = ((int) SysVar::GetPFont()>-1) ? 1 : 0;
+  std::string what = "hrshsym=0,text=" + i2s(myfont);
+  actStream->setopt("drvopt", what.c_str());
+  
+   actStream->spage(Z_DPI, Z_DPI, nx, ny, 0, 0 );
 
-    actStream->setopt( "drvopt","text=0"); // clear drvopt
-
-    actStream->Init();
-   // need to be called initially. permit to fix things
-    actStream->ssub(1,1);
-    actStream->adv(0);
+   actStream->Init();
+    // need to be called initially. permit to fix things
+    actStream->plstream::ssub(1, 1); // plstream below stays with ONLY ONE page
+    actStream->plstream::adv(0); //-->this one is the 1st and only pladv
     // load font
-    actStream->font( 1);
-    actStream->vpor(0,1,0,1);
-    actStream->wind(0,1,0,1);
+    actStream->plstream::font(1);
+    actStream->plstream::vpor(0, 1, 0, 1);
+    actStream->plstream::wind(0, 1, 0, 1);
+
+    actStream->ssub(1, 1);
+    actStream->SetPageDPMM();
     actStream->DefaultCharSize();
-//   //in case these are not initalized, here is a good place to do it.
-//    if (actStream->updatePageInfo()==true)
-//    {
-//        actStream->GetPlplotDefaultCharSize(); //initializes everything in fact..
-//
-//    }
+    actStream->adv(0); //this is for us (counters) //needs DefaultCharSize
   }
 
 public:
@@ -256,6 +245,9 @@ public:
   {
     return decomposed;  
   }
+    
+    virtual bool SetFont(DString &f) final {fontname=f; return true;}
+
 };
 
 #endif
