@@ -29,14 +29,129 @@
 
 // print out AST tree
 //#define GDL_DEBUG
-#undef GDL_DEBUG
+//#undef GDL_DEBUG
 
 #ifdef GDL_DEBUG
 #include "print_tree.hpp"
 #endif
 
+SCCodeListT     sccList;
+
 using namespace std;
 
+  bool is_nonleaf(RefDNode node) {
+	bool rslt = (node->getFirstChild() != NULL);
+	return rslt;
+  }
+  void process_top(RefDNode top, SCCStructV &nodes, SCCodeAddresses &addrList);
+  
+  //write a "Node" : current memory address (serves as identifier), type, text, cdata, down( aka GetFirstChild) , right (aka getNextSibling)
+
+  void convertNodeToStruct(RefDNode node, SCCStructV &nodes, SCCodeAddresses &addrList) {
+    sccstruct savenode;
+    SCCodeAddressesIterator it;
+	// address is not that simple to retrieve. The address is what ' std::cout<<this " prints, and it is NOT easy to get it right. 'This is the way'.
+	DNode* ast=node.get();
+	if (ast->GetVar() != NULL) std::cerr<<"Var = "<<ast->GetVar()<<std::endl; //TBD: check if var is used.
+	RefDNode dNode = static_cast<RefDNode> (node);
+	//write node index
+    it = addrList.find(ast);
+	if (it != addrList.end()) savenode.node = (*it).second; else savenode.node =0;
+	RefDNode right = dNode->GetNextSibling();
+	ast = right.get();
+    it = addrList.find(ast);
+	if (it != addrList.end()) savenode.right = (*it).second; else savenode.right =0;
+	RefDNode down = dNode->GetFirstChild();
+	ast = down.get();
+    it = addrList.find(ast);
+	if (it != addrList.end()) savenode.down = (*it).second; else savenode.down =0;
+	savenode.nodeType=dNode->getType();
+	savenode.ligne = dNode->getLine();
+	savenode.flags=dNode->GetCompileOpt();
+	// trick to avoid saving a Text and a CData containing the same text, either as a string or a value converted to the good BaseGDL type.
+	// if dNode->CData() is non-nil, set savenode.Text to "" and save CData as copy.
+	if (dNode->CData() != NULL) {
+	  savenode.var=dNode->CData()->Convert2(dNode->CData()->Type(),BaseGDL::COPY);
+	  savenode.Text = "";
+	} else  savenode.Text = dNode->getText(); 
+    nodes.push_back(savenode);
+  } 
+
+  void process_leaves(RefDNode top, SCCStructV &nodes, SCCodeAddresses &addrList) {
+	RefDNode t;
+
+	for (t = ((top && is_nonleaf(top)) ? top->getFirstChild() : (RefDNode) NULL); t; t = t->getNextSibling()) {
+	  if (is_nonleaf(t))
+		process_top(t,nodes,addrList);
+	  else
+		convertNodeToStruct(t,nodes,addrList);
+	}
+  } 
+
+  void process_top(RefDNode top, SCCStructV &nodes, SCCodeAddresses &addrList) {
+	RefDNode t;
+	bool first = true;
+
+	convertNodeToStruct(top,nodes,addrList);
+
+	if (is_nonleaf(top)) {
+	  for (t = ((top && is_nonleaf(top)) ? top->getFirstChild() : (RefDNode) NULL); t; t = t->getNextSibling()) {
+		if (is_nonleaf(t))
+		  first = false;
+	  }
+	  process_leaves(top,nodes,addrList);
+	}
+  }
+ //same as index_tree: no not use
+  void process_tree(RefDNode top, SCCStructV &nodes, SCCodeAddresses &addrList) {
+  std::cerr<<"use of process_tree, please report."<<std::endl;
+  assert(false);
+  RefDNode t;
+	for (t = top; t != NULL; t = t->getNextSibling()) {
+	  process_top(t,nodes,addrList);
+	}
+}
+ 
+//walks and associate an integer index with node address.  
+void index_top(RefDNode top, SCCodeAddresses &addrList, int &i);
+void indexNodeAddress(RefDNode node, SCCodeAddresses &addrList, int &i) {
+// associate node address to an increasing number starting at 1
+  DNode* ast = node.get();
+  addrList.insert(std::pair<DNode*,int>(ast, ++i)); //+1 as address 0 is special for all nodes
+  }
+
+void index_leaves(RefDNode top, SCCodeAddresses &addrList, int &i) {
+  RefDNode t;
+  for (t = ((top && is_nonleaf(top)) ? top->getFirstChild() : (RefDNode) NULL); t; t = t->getNextSibling()) {
+	if (is_nonleaf(t))
+	  index_top(t,addrList, i);
+	else
+	  indexNodeAddress(t,addrList, i);
+  }
+}
+
+void index_top(RefDNode top, SCCodeAddresses &addrList, int &i) {
+  RefDNode t;
+  bool first = true;
+  indexNodeAddress(top,addrList, i);
+  if (is_nonleaf(top)) {
+	for (t = ((top && is_nonleaf(top)) ? top->getFirstChild() : (RefDNode) NULL); t; t = t->getNextSibling()) {
+	  if (is_nonleaf(t))
+		first = false;
+	}
+	index_leaves(top,addrList, i);
+  }
+}
+
+//this would be to index a full tree, but our use at the time is of index_top, that serialize only the current PRO or FUN .
+void index_tree(RefDNode top, SCCodeAddresses &addrList, int &i) {
+  std::cerr<<"use of index_tree, please report."<<std::endl;
+  assert(false);
+  RefDNode t;
+  for (t = top; t != NULL; t = t->getNextSibling()) {
+	index_top(t, addrList, i);
+  }
+}
 // vtable
 DSub::~DSub() {}
 
@@ -44,7 +159,7 @@ DSub::~DSub() {}
 // DLib ******************************************************
 DLib::DLib( const string& n, const string& o, const int nPar_, 
 	    const string keyNames[],
-	    const string warnKeyNames[], const int nParMin_)
+	    const string warnKeyNames[], const int nParMin_, const bool use_threadpool)
   : DSub(n,o)
   , hideHelp( false)
 {
@@ -57,19 +172,20 @@ DLib::DLib( const string& n, const string& o, const int nPar_,
     {
       while( keyNames[nKey_] != "") ++nKey_;
     }
-
+  
   key.resize(nKey_);
-  for( SizeT k=0; k<nKey_; ++k) key[k]=keyNames[k];
+  SizeT k=0;
+  for( ; k<nKey_; ++k) key[k]=keyNames[k];
 
   if( nKey_ >= 1) {
     if( keyNames[0] == "_EXTRA")
       {
-	extra = EXTRA;
+	extra_type = EXTRA;
 	extraIx = 0;
       }
     else if( keyNames[0] == "_REF_EXTRA")
       {
-	extra = REFEXTRA;
+	extra_type = REFEXTRA;
 	extraIx = 0;
       }
   }
@@ -81,7 +197,16 @@ DLib::DLib( const string& n, const string& o, const int nPar_,
     }
 
   warnKey.resize(nWarnKey_);
-  for( SizeT wk=0; wk<nWarnKey_; ++wk) warnKey[wk]=warnKeyNames[wk];
+  SizeT wk=0;
+  for( ; wk<nWarnKey_; ++wk) warnKey[wk]=warnKeyNames[wk];
+//finally add threadpool kw if any, in warnkeys at the moment, since we do not really honor those kws.
+  if (use_threadpool) {
+    nWarnKey_ += 3;
+    warnKey.resize(nWarnKey_);
+    warnKey[wk++] = "TPOOL_MAX_ELTS";
+    warnKey[wk++] = "TPOOL_MIN_ELTS";
+    warnKey[wk++] = "TPOOL_NOTHREAD";
+  }
 }
 
 const string DLibPro::ToString()
@@ -182,8 +307,8 @@ DLibPro::DLibPro( LibPro p, const string& n, const string& o, const int nPar_,
 //  sort(libProList.begin(), libProList.end(),CompLibFunName());
 }
 DLibPro::DLibPro( LibPro p, const string& n, const int nPar_, 
-		  const string keyNames[], const string warnKeyNames[], const int nParMin_)
-  : DLib(n,"",nPar_,keyNames, warnKeyNames, nParMin_), pro(p)
+		  const string keyNames[], const string warnKeyNames[], const int nParMin_, const bool use_threadpool)
+  : DLib(n,"",nPar_,keyNames, warnKeyNames, nParMin_, use_threadpool), pro(p)
 {
   libProList.push_back(this);
 //  sort(libProList.begin(), libProList.end(),CompLibFunName());
@@ -198,12 +323,13 @@ DLibFun::DLibFun( LibFun f, const string& n, const string& o, const int nPar_,
 }
 
 DLibFun::DLibFun( LibFun f, const string& n, const int nPar_, 
-		  const string keyNames[], const string warnKeyNames[], const int nParMin_)
-  : DLib(n,"",nPar_,keyNames, warnKeyNames, nParMin_), fun(f)
+		  const string keyNames[], const string warnKeyNames[], const int nParMin_, const bool use_threadpool)
+  : DLib(n,"",nPar_,keyNames, warnKeyNames, nParMin_, use_threadpool), fun(f)
 {
   libFunList.push_back(this);
 //  sort(libFunList.begin(), libFunList.end(),CompLibFunName());
 }
+
 DLibFunRetNew::DLibFunRetNew( LibFun f, const string& n, 
 			      const string& o, const int nPar_, 
 			      const string keyNames[], const string warnKeyNames[], const int nParMin_)
@@ -215,6 +341,12 @@ DLibFunRetNew::DLibFunRetNew( LibFun f, const string& n, const int nPar_,
 			      const int nParMin_)
   : DLibFun(f,n,nPar_,keyNames, warnKeyNames, nParMin_), retConstant( rConstant)
 {}
+
+DLibFunRetNewTP::DLibFunRetNewTP( LibFun f, const string& n, const int nPar_, 
+			      const string keyNames[], const string warnKeyNames[], bool rConstant,
+			      const int nParMin_)
+  : DLibFun(f,n,nPar_,keyNames, warnKeyNames, nParMin_, true), retConstant( rConstant)
+{}
 // DLibFunRetNew::DLibFunRetNew( LibFun f, const string& n, const int nPar_, 
 // 			bool rConstant)
 //   : DLibFun(f,n,nPar_,NULL, NULL), retConstant( rConstant)
@@ -226,6 +358,9 @@ DLibFunDirect::DLibFunDirect( LibFunDirect f, const std::string& n, bool rConsta
   : DLibFunRetNew(NULL,n,1,NULL,NULL,rConstant,1), funDirect(f)
 {}
 
+DLibFunDirectTP::DLibFunDirectTP( LibFunDirect f, const std::string& n, bool rConstant)
+  : DLibFunRetNewTP(NULL,n,1,NULL,NULL,rConstant,1), funDirect(f)
+{}
 
 // DSubUD ****************************************************
 DSubUD::~DSubUD()
@@ -240,6 +375,7 @@ DSubUD::~DSubUD()
 
   labelList.Clear();
   delete tree;
+  sccList.erase(this);
 }
 
 DSubUD::DSubUD(const string& n,const string& o,const string& f) : 
@@ -297,18 +433,18 @@ DSubUD* DSubUD::AddKey(const string& k, const string& v)
 {
   if( k == "_REF_EXTRA")
     {
-      if( extra == EXTRA)
+      if( extra_type == EXTRA)
 	throw GDLException("Routines cannot be declared with both"
 			   " _EXTRA and _REF_EXTRA.");
-      extra=REFEXTRA;
+      extra_type=REFEXTRA;
       extraIx=0;
     }
   else if( k == "_EXTRA")
     {
-      if( extra == REFEXTRA)
+      if( extra_type == REFEXTRA)
 	throw GDLException("Routines cannot be declared with both"
 			   " _EXTRA and _REF_EXTRA.");
-      extra=EXTRA;
+      extra_type=EXTRA;
       extraIx=0;
     }
   else
@@ -393,7 +529,21 @@ void DSubUD::SetTree( RefDNode n)
 #endif
 
 }
+//converts a SemiCompiledCode (chained list of DNodes) to a 'flat' vector of sccstruct and insert the vector in the map pointed by "sccList"
 
+void DSubUD::SetSCC(RefDNode n) {
+  //first, walk RefDnode tree to associate right,down, and self addresses with a number in the list.
+  SCCodeAddresses addrList;
+  int i=0;
+  //serialize only the current PRO or FUN by using index_top and *not* index_tree.
+  index_top(n, addrList, i);
+  SCCStructV sccv;
+  process_top(n, sccv, addrList);
+	//PRO or FUNCTION top node may contain a 'wrong' right pointer in the first node, due to the way the whole .pro file is compiled at once.
+	//Remove it:
+  sccv[0].right=0;
+  sccList.insert(std::pair<DSubUD*,SCCStructV >(this, sccv));
+}
 bool DSubUD::GetCommonVarName(const BaseGDL* p, std::string& varName)
 {
   CommonBaseListT::iterator it;
@@ -453,3 +603,17 @@ bool DSubUD::isHidden()
   return compileOpt & GDLParser::HIDDEN;
 }
 
+bool DSubUD::isGdlHidden()
+{
+  return compileOpt & GDLParser::GDL_HIDDEN;
+}
+
+bool DSubUD::isNoSave()
+{
+  return compileOpt & GDLParser::NOSAVE;
+}
+
+void DSubUD::AddHiddenToCompileOpt() {
+  compileOpt |= GDLParser::GDL_HIDDEN;
+}
+
