@@ -18,6 +18,7 @@
 #define GDL_JOURNAL_C
 
 #include "includefirst.hpp"
+#include "version.hpp"
 
 #ifndef _MSC_VER
 #include <unistd.h>
@@ -26,7 +27,6 @@
 #include <fstream>
 #include <sys/stat.h>
 
-#include "envt.hpp"
 #include "dinterpreter.hpp"
 #include "gdljournal.hpp"
 #include "io.hpp"
