@@ -28,30 +28,34 @@ private:
   bool encapsulated;
   bool portrait;
   long bitsPerPix;
+  bool firstTime; //to enable a PS hack on correspondence postscript pixels - plplot position. 
 public:
   GDLPSStream( int nx, int ny, int pfont, bool encaps, int color, int bpp, bool orient_portrait):
-#ifdef _MSC_VER
-    GDLGStream( nx, ny, /*pfont == 1 ? "psttf" :*/ (color==0)?"ps":"psc")
-#else
-    GDLGStream::GDLGStream( nx, ny, /*pfont == 1 ? "psttf" :*/(color==0)?"ps":"psc")
-#endif
+  GDLGStream::GDLGStream( nx, ny, (color==0)?"ps":"psc")
   {
     encapsulated = encaps;
     page = 0;
     portrait = orient_portrait;
     bitsPerPix=bpp;
+    firstTime=true;
   }
 
-  ~GDLPSStream()
-  {}
+  ~GDLPSStream(){}
  
   void eop();
 
   void Init();
   bool PaintImage(unsigned char *idata, PLINT nx, PLINT ny,  DLong *pos, DLong tru, DLong chan);
   //logically close the svg each time an update is made, then rollback to the last graphic section for further graphics.
-  void Update(){plstream::cmd(PLESC_EXPOSE, NULL);fprintf(pls->OutFile," S\neop\n");fseek(pls->OutFile,-7, SEEK_END);} 
-  float GetPlplotFudge(){return 1;}; //correction factor 
+  //the adding of pls->stream_closed=XXX is just due to avoid bug https://sourceforge.net/p/plplot/bugs/203/ at least in the sens it does not crash GDL
+  void Update(){plstream::cmd(PLESC_EXPOSE, NULL);pls->stream_closed=1;fprintf(pls->OutFile," S\neop\n");fseek(pls->OutFile,-7, SEEK_END);pls->stream_closed=0;}
+//  void Update(){}
+
+  virtual void fontChanged() final {
+    PLINT doFont = ((PLINT) SysVar::GetPFont()>-1) ? 1 : 0;
+    pls->dev_text = doFont;
+  }
+  
 };
 
 #endif
