@@ -41,7 +41,6 @@ private:
     int m_width;   //!< Width of dc/plot area.
     int m_height;   //!< Height of dc/plot area.
     bool isplot; //precise the status of associated widget: plot (true) or widget_draw (false)
-    bool olddriver; //memory of if the wxwidgets driver is old, and thus... OK: reliable and fast!
 public:
     gdlwxGraphicsPanel* container; // for Update()
 
@@ -100,10 +99,8 @@ public:
     virtual DByteGDL* GetBitmapData(int xoff, int yoff, int nx, int ny) final;
     static void DefineSomeWxCursors(); //global initialisation of 77 X11-like cursors.
     virtual void fontChanged() final {
-     if (olddriver) {
       PLINT doFont = ((PLINT) SysVar::GetPFont()>-1) ? 1 : 0;
       pls->dev_text = doFont;
-     }
     }
 };
 
