@@ -104,7 +104,10 @@ bool GDLXStream::SetGraphicsFunction( long value) {
     gcValues.function = (value<0)?0:(value>15)?15:value;
     XwDev *dev = (XwDev *) pls->dev;
     XwDisplay *xwd = (XwDisplay *) dev->xwd;
-    return XChangeGC( xwd->display, dev->gc, GCFunction, &gcValues );
+//    int ret=XChangeGC( xwd->display, dev->gc, GCFunction, &gcValues );
+	
+	plstream::cmd( PLESC_XORMOD, &value );
+	return true;
 }
 
 bool GDLXStream::GetWindowPosition(long& xpos, long& ypos ) {
@@ -359,6 +362,9 @@ void GDLXStream::UnSetDoubleBuffering() {
   pls->db = 0;
 }
 
+void GDLXStream::UglyPatchMakeHidden() {
+  pls->arrow_npts=999;
+}
 //modified version. Will not tell double buffering is available if current graphic function is not pure "copy".
 bool GDLXStream::HasSafeDoubleBuffering() {
     XwDev *dev = (XwDev *) pls->dev;
