@@ -18,14 +18,14 @@
 #ifndef IMAGE_HPP_
 #define IMAGE_HPP_
 
-#include <plplot/plstream.h>
-
 #include "envt.hpp"
+#include "initsysvar.hpp"
 
 namespace lib {
 
   void loadct( EnvT* e);
   BaseGDL* tvrd( EnvT* e);
+  BaseGDL* GetImage( EnvT* e);
 
 } // namespace
 
