@@ -15,18 +15,9 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "includefirst.hpp"
-
 #include <memory>
-
-#include <antlr/ASTFactory.hpp>
-
 #include "dinterpreter.hpp"
 #include "prognodeexpr.hpp"
-#include "basegdl.hpp"
-#include "arrayindexlistt.hpp"
-#include "envt.hpp"
-#include "gdlexception.hpp"
 
 // print out AST tree
 //#define GDL_DEBUG
